# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.combat_log_upload_v2_response import CombatLogUploadV2Response

class TestCombatLogUploadV2Response(unittest.TestCase):
    """CombatLogUploadV2Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombatLogUploadV2Response:
        """Test CombatLogUploadV2Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombatLogUploadV2Response`
        """
        model = CombatLogUploadV2Response()
        if include_optional:
            return CombatLogUploadV2Response(
                results = [
                    OSCR_django_client.models.combat_log_upload_response.CombatLogUploadResponse(
                        name = '0', 
                        updated = True, 
                        detail = '0', 
                        value = 1.337, )
                    ],
                combatlog = 56,
                detail = '0'
            )
        else:
            return CombatLogUploadV2Response(
                detail = '0',
        )
        """

    def testCombatLogUploadV2Response(self):
        """Test CombatLogUploadV2Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
