# coding: utf-8

# flake8: noqa

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2025.7.19.0"

# Define package exports
__all__ = [
    "CombatlogApi",
    "LadderApi",
    "LadderEntriesApi",
    "SystemApi",
    "VariantApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CombatLog",
    "CombatLogUploadResponse",
    "CombatLogUploadV2Response",
    "CombatlogList200Response",
    "Ladder",
    "LadderEntriesList200Response",
    "LadderEntry",
    "LadderList200Response",
    "Metadata",
    "Update",
    "Variant",
    "VariantList200Response",
]

# import apis into sdk package
from OSCR_django_client.api.combatlog_api import CombatlogApi as CombatlogApi
from OSCR_django_client.api.ladder_api import LadderApi as LadderApi
from OSCR_django_client.api.ladder_entries_api import LadderEntriesApi as LadderEntriesApi
from OSCR_django_client.api.system_api import SystemApi as SystemApi
from OSCR_django_client.api.variant_api import VariantApi as VariantApi

# import ApiClient
from OSCR_django_client.api_response import ApiResponse as ApiResponse
from OSCR_django_client.api_client import ApiClient as ApiClient
from OSCR_django_client.configuration import Configuration as Configuration
from OSCR_django_client.exceptions import OpenApiException as OpenApiException
from OSCR_django_client.exceptions import ApiTypeError as ApiTypeError
from OSCR_django_client.exceptions import ApiValueError as ApiValueError
from OSCR_django_client.exceptions import ApiKeyError as ApiKeyError
from OSCR_django_client.exceptions import ApiAttributeError as ApiAttributeError
from OSCR_django_client.exceptions import ApiException as ApiException

# import models into sdk package
from OSCR_django_client.models.combat_log import CombatLog as CombatLog
from OSCR_django_client.models.combat_log_upload_response import CombatLogUploadResponse as CombatLogUploadResponse
from OSCR_django_client.models.combat_log_upload_v2_response import CombatLogUploadV2Response as CombatLogUploadV2Response
from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response as CombatlogList200Response
from OSCR_django_client.models.ladder import Ladder as Ladder
from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response as LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry as LadderEntry
from OSCR_django_client.models.ladder_list200_response import LadderList200Response as LadderList200Response
from OSCR_django_client.models.metadata import Metadata as Metadata
from OSCR_django_client.models.update import Update as Update
from OSCR_django_client.models.variant import Variant as Variant
from OSCR_django_client.models.variant_list200_response import VariantList200Response as VariantList200Response
